// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "RPGPlayer.hpp"
#include "scene/Scene.hpp"
#include "RPGEntity.hpp"

using namespace Dawn;

void RPGPlayer::onInit() {
  events.push_back(getScene()->onUnpausedUpdate.listen([&](
    float_t d
  ) {
    glm::vec2 movement = getGame()->inputManager.getAxis2D(
      InputBind::LEFT, InputBind::RIGHT,
      InputBind::UP, InputBind::DOWN
    );

    if(movement.x != 0 || movement.y != 0) {
      // Normalize angle.
      float_t angle = atan2(movement.x, movement.y);
      angle -= Math::deg2rad(90.0f);
      movement = glm::vec2(cosf(angle), sinf(angle)) * PLAYER_SPEED * d;

      // Update position.
      auto ePos = getItem()->getLocalPosition();
      ePos.x += movement.x;
      ePos.y += movement.y;
      getItem()->setLocalPosition(ePos);
    }

    if(this->camera != nullptr) {
      this->camera->lookAtPixelPerfect(
        getItem()->getLocalPosition() + glm::vec3(0, -32.0f, 0),
        getItem()->getLocalPosition(),
        2.0f
      );
    }
  }));
}

void RPGPlayer::onDispose() {
  
}