
// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "scene/SceneList.hpp"
#include "component/display/Camera.hpp"
#include "prefab/SimpleSpinningCube.hpp"
#include "component/display/material/SimpleTexturedMaterial.hpp"
#include "display/mesh/QuadMesh.hpp"
#include "component/ui/UICanvas.hpp"

#include "component/RPGEntity.hpp"
#include "component/RPGPlayer.hpp"

using namespace Dawn;

void Dawn::helloWorldScene(Scene &s) {
  while(!s.getGame()->assetManager->isEverythingLoaded()) {
    s.getGame()->assetManager->update();
  }

  auto cameraItem = s.createSceneItem();
  auto camera = cameraItem->addComponent<Camera>();
  camera->clipFar = 99999.99f;

  auto player = s.createSceneItem();

  glm::vec2 size = { RPG_ENTITY_SIZE, RPG_ENTITY_SIZE };
  glm::vec2 position = -size;
  auto quadMesh = std::make_shared<Mesh>();
  quadMesh->createBuffers(QUAD_VERTICE_COUNT, QUAD_INDICE_COUNT);
  QuadMesh::buffer(
    quadMesh,
    glm::vec4(position.x, position.y, size.x, size.y),
    glm::vec4(0, 0, 1, 1),
    0, 0, 0
  );

  auto quadRenderer = player->addComponent<MeshRenderer>();
  quadRenderer->mesh = quadMesh;

  auto quadMaterial = player->addComponent<SimpleTexturedMaterial>();
  quadMaterial->setColor(COLOR_WHITE);

  auto ent = player->addComponent<RPGEntity>();

  auto ePlyr = player->addComponent<RPGPlayer>();
  ePlyr->camera = camera;

  auto uiCanvasItem = s.createSceneItem();
  auto uiCanvas = uiCanvasItem->addComponent<UICanvas>();
}